@@ -7,7 +7,7 @@
    This file is part of Valgrind, a dynamic binary instrumentation
    framework.
 
-   Copyright (C) 2000-2006 Nicholas Nethercote
+   Copyright (C) 2000-2007 Nicholas Nethercote
       njn@valgrind.org
 
    This program is free software; you can redistribute it and/or
@@ -1189,7 +1189,7 @@ const SyscallTableEntry ML_(syscall_table)[] = {
 
    //   (__NR_pivot_root,        sys_pivot_root),     // 155 
    LINXY(__NR__sysctl,           sys_sysctl),         // 156 
-   LINX_(__NR_prctl,             sys_prctl),          // 157 
+   LINXY(__NR_prctl,             sys_prctl),          // 157 
    PLAX_(__NR_arch_prctl,	 sys_arch_prctl),     // 158 
    //   (__NR_adjtimex,          sys_adjtimex),       // 159 
 
@@ -1325,7 +1325,7 @@ const SyscallTableEntry ML_(syscall_table)[] = {
    LINX_(__NR_fchmodat,		 sys_fchmodat),         // 268
    LINX_(__NR_faccessat,	 sys_faccessat),        // 269
 
-//   LINX_(__NR_pselect6,		 sys_ni_syscall),       // 270
+   LINX_(__NR_pselect6,		 sys_pselect6),         // 270
 //   LINXY(__NR_ppoll,		 sys_ni_syscall),       // 271
 //   LINX_(__NR_unshare,		 sys_unshare),          // 272
    LINX_(__NR_set_robust_list,	 sys_set_robust_list),  // 273
